=======================
``support.dawg`` module
=======================

.. automodule:: whoosh.support.dawg


Graph nodes
===========

.. autoclass:: BaseNode
    :members:

.. autoclass:: UnionNode
.. autoclass:: IntersectionNode


Utility functions
=================

.. autofunction:: edge_count
.. autofunction:: flatten
.. autofunction:: dump_dawg
.. autofunction:: within

